coherence.backends.radiotime_storage (module) — Cohen3 0.8.0 documentation

# coherence.backends.radiotime_storage (module)

class `RadiotimeAudioItem`(outline)

  Bases: `coherence.backend.BackendItem`

  `logCategory` = 'radiotime'
  `replace_by`(item)
  `get_item`()

    Called by the CDS and the MediaServer web.

    Returns: | an UPnP ContentDirectoryServer DIDLLite object or a Deferred

  `get_path`()

    Called by the MediaServer web.

    Returns: | the filepath where to find the media file that this item does refer to.

  `get_id`()

class `RadiotimeStore`(server, **kwargs)

  Bases: `coherence.backend.AbstractBackendStore`

  `logCategory` = 'radiotime'
  `implements` = ['MediaServer']
  `upnp_init`()

    This method gets called after the device is fired, here all initializations of service related state variables should happen, as the services aren’t available before that point.

  `retrieveItemsForOPML`(parent, url)